libpldm:Change in the PlatformEventMessage field

This commit does a change in the field name in
PlatformEventMessage responder flow encode, to
allign the naming to the spec.

Tested: with unit tests

Change-Id: I309cdfbf6ebc213944676912246e7fe5e825706b
Signed-off-by: Pavithra Barithaya <pbaritha@in.ibm.com>
diff --git a/libpldm/platform.h b/libpldm/platform.h
index 5bb110c..dd99633 100644
--- a/libpldm/platform.h
+++ b/libpldm/platform.h
@@ -407,7 +407,7 @@
  */
 struct pldm_platform_event_message_resp {
 	uint8_t completion_code;
-	uint8_t status;
+	uint8_t platform_event_status;
 } __attribute__((packed));
 
 /** @struct pldm_pdr_repository_chg_event_data
@@ -853,14 +853,16 @@
 /** @brief Encode PlatformEventMessage response data
  *  @param[in] instance_id - Message's instance id
  *  @param[in] completion_code - PLDM completion code
  *  @param[in] status - Response status of the event message command
  *  @param[out] msg - Message will be written to this
  *  @return pldm_completion_codes
  *  @note  Caller is responsible for memory alloc and dealloc of param
  *         'msg.payload'
  */
 int encode_platform_event_message_resp(uint8_t instance_id,
-				       uint8_t completion_code, uint8_t status,
+				       uint8_t completion_code,
+				       uint8_t platform_event_status,
 				       struct pldm_msg *msg);
 
 /** @brief Decode sensorEventData response data
@@ -853,14 +853,16 @@
  *  @param[in] instance_id - Message's instance id
  *  @param[in] completion_code - PLDM completion code
- *  @param[in] status - Response status of the event message command
+ *  @param[in] platform_event_status - Response status of the event message
+ * command
  *  @param[out] msg - Message will be written to this
  *  @return pldm_completion_codes